Re: [PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode

2015-08-02 Thread Markus Pargmann
On Fri, Jul 31, 2015 at 05:13:06PM +0200, Maciej S. Szmigiero wrote:
 On 31.07.2015 07:58, Markus Pargmann wrote:
  On Thu, Jul 30, 2015 at 04:35:58PM +0200, Maciej S. Szmigiero wrote:
  Adjust set DAI format function in fsl_ssi driver so it
  doesn't fail and clears RXDIR in AC'97 mode.
 
  Signed-off-by: Maciej Szmigiero m...@maciej.szmigiero.name
  ---
   sound/soc/fsl/fsl_ssi.c |8 +---
   1 files changed, 5 insertions(+), 3 deletions(-)
 
  diff --git a/sound/soc/fsl/fsl_ssi.c b/sound/soc/fsl/fsl_ssi.c
  index 8e5ff5e..37aabe3 100644
  --- a/sound/soc/fsl/fsl_ssi.c
  +++ b/sound/soc/fsl/fsl_ssi.c
  @@ -900,14 +900,16 @@ static int _fsl_ssi_set_dai_fmt(struct device *dev,
 scr = ~CCSR_SSI_SCR_SYS_CLK_EN;
 break;
 default:
  -  return -EINVAL;
  +  if (!fsl_ssi_is_ac97(ssi_private))
  +  return -EINVAL;
  
  I think it would be better to add another case for the other mode which
  is supported (AC97) instead of using the default case.
 
 This is a switch of DAI clock masters and AC'97 is none of them:
 while case 0: can be added this would be very similar to the current code.
 
 Alternatively, the whole switch statement could be wrapped inside
 if (!fsl_ssi_is_ac97(ssi_private)) if that would be better
 with regards to code style.

I looked at the wrong switch/case the DAIFMT_AC97 is actually used
but this patch is about the master clocks. It's fine then.

Thanks,

Markus

 
 }
   
 stcr |= strcr;
 srcr |= strcr;
   
  -  if (ssi_private-cpu_dai_drv.symmetric_rates) {
  -  /* Need to clear RXDIR when using SYNC mode */
  +  if (ssi_private-cpu_dai_drv.symmetric_rates
  +  || fsl_ssi_is_ac97(ssi_private)) {
  
  Please fix this indention. Most of the driver is written with 2 tab
  indention after a line break and the new policy seems to be to indent on
  the opening bracket.
 
 Will reindent this.
 
  
  Regards,
  
  Markus
 
 Best regards,
 Maciej Szmigiero
 
 

-- 
Pengutronix e.K.   | |
Industrial Linux Solutions | http://www.pengutronix.de/  |
Peiner Str. 6-8, 31137 Hildesheim, Germany | Phone: +49-5121-206917-0|
Amtsgericht Hildesheim, HRA 2686   | Fax:   +49-5121-206917- |


signature.asc
Description: Digital signature
___
Linuxppc-dev mailing list
Linuxppc-dev@lists.ozlabs.org
https://lists.ozlabs.org/listinfo/linuxppc-dev

Re: [PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode

2015-07-31 Thread Maciej S. Szmigiero
On 31.07.2015 07:58, Markus Pargmann wrote:
 On Thu, Jul 30, 2015 at 04:35:58PM +0200, Maciej S. Szmigiero wrote:
 Adjust set DAI format function in fsl_ssi driver so it
 doesn't fail and clears RXDIR in AC'97 mode.

 Signed-off-by: Maciej Szmigiero m...@maciej.szmigiero.name
 ---
  sound/soc/fsl/fsl_ssi.c |8 +---
  1 files changed, 5 insertions(+), 3 deletions(-)

 diff --git a/sound/soc/fsl/fsl_ssi.c b/sound/soc/fsl/fsl_ssi.c
 index 8e5ff5e..37aabe3 100644
 --- a/sound/soc/fsl/fsl_ssi.c
 +++ b/sound/soc/fsl/fsl_ssi.c
 @@ -900,14 +900,16 @@ static int _fsl_ssi_set_dai_fmt(struct device *dev,
  scr = ~CCSR_SSI_SCR_SYS_CLK_EN;
  break;
  default:
 -return -EINVAL;
 +if (!fsl_ssi_is_ac97(ssi_private))
 +return -EINVAL;
 
 I think it would be better to add another case for the other mode which
 is supported (AC97) instead of using the default case.

This is a switch of DAI clock masters and AC'97 is none of them:
while case 0: can be added this would be very similar to the current code.

Alternatively, the whole switch statement could be wrapped inside
if (!fsl_ssi_is_ac97(ssi_private)) if that would be better
with regards to code style.

  }
  
  stcr |= strcr;
  srcr |= strcr;
  
 -if (ssi_private-cpu_dai_drv.symmetric_rates) {
 -/* Need to clear RXDIR when using SYNC mode */
 +if (ssi_private-cpu_dai_drv.symmetric_rates
 +|| fsl_ssi_is_ac97(ssi_private)) {
 
 Please fix this indention. Most of the driver is written with 2 tab
 indention after a line break and the new policy seems to be to indent on
 the opening bracket.

Will reindent this.

 
 Regards,
 
 Markus

Best regards,
Maciej Szmigiero

___
Linuxppc-dev mailing list
Linuxppc-dev@lists.ozlabs.org
https://lists.ozlabs.org/listinfo/linuxppc-dev

[PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode

2015-07-30 Thread Maciej S. Szmigiero
Adjust set DAI format function in fsl_ssi driver so it
doesn't fail and clears RXDIR in AC'97 mode.

Signed-off-by: Maciej Szmigiero m...@maciej.szmigiero.name
---
 sound/soc/fsl/fsl_ssi.c |8 +---
 1 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/sound/soc/fsl/fsl_ssi.c b/sound/soc/fsl/fsl_ssi.c
index 8e5ff5e..37aabe3 100644
--- a/sound/soc/fsl/fsl_ssi.c
+++ b/sound/soc/fsl/fsl_ssi.c
@@ -900,14 +900,16 @@ static int _fsl_ssi_set_dai_fmt(struct device *dev,
scr = ~CCSR_SSI_SCR_SYS_CLK_EN;
break;
default:
-   return -EINVAL;
+   if (!fsl_ssi_is_ac97(ssi_private))
+   return -EINVAL;
}
 
stcr |= strcr;
srcr |= strcr;
 
-   if (ssi_private-cpu_dai_drv.symmetric_rates) {
-   /* Need to clear RXDIR when using SYNC mode */
+   if (ssi_private-cpu_dai_drv.symmetric_rates
+   || fsl_ssi_is_ac97(ssi_private)) {
+   /* Need to clear RXDIR when using SYNC or AC97 mode */
srcr = ~CCSR_SSI_SRCR_RXDIR;
scr |= CCSR_SSI_SCR_SYN;
}

___
Linuxppc-dev mailing list
Linuxppc-dev@lists.ozlabs.org
https://lists.ozlabs.org/listinfo/linuxppc-dev

Re: [PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode

2015-07-30 Thread Markus Pargmann
On Thu, Jul 30, 2015 at 04:35:58PM +0200, Maciej S. Szmigiero wrote:
 Adjust set DAI format function in fsl_ssi driver so it
 doesn't fail and clears RXDIR in AC'97 mode.
 
 Signed-off-by: Maciej Szmigiero m...@maciej.szmigiero.name
 ---
  sound/soc/fsl/fsl_ssi.c |8 +---
  1 files changed, 5 insertions(+), 3 deletions(-)
 
 diff --git a/sound/soc/fsl/fsl_ssi.c b/sound/soc/fsl/fsl_ssi.c
 index 8e5ff5e..37aabe3 100644
 --- a/sound/soc/fsl/fsl_ssi.c
 +++ b/sound/soc/fsl/fsl_ssi.c
 @@ -900,14 +900,16 @@ static int _fsl_ssi_set_dai_fmt(struct device *dev,
   scr = ~CCSR_SSI_SCR_SYS_CLK_EN;
   break;
   default:
 - return -EINVAL;
 + if (!fsl_ssi_is_ac97(ssi_private))
 + return -EINVAL;

I think it would be better to add another case for the other mode which
is supported (AC97) instead of using the default case.

   }
  
   stcr |= strcr;
   srcr |= strcr;
  
 - if (ssi_private-cpu_dai_drv.symmetric_rates) {
 - /* Need to clear RXDIR when using SYNC mode */
 + if (ssi_private-cpu_dai_drv.symmetric_rates
 + || fsl_ssi_is_ac97(ssi_private)) {

Please fix this indention. Most of the driver is written with 2 tab
indention after a line break and the new policy seems to be to indent on
the opening bracket.

Regards,

Markus

 + /* Need to clear RXDIR when using SYNC or AC97 mode */
   srcr = ~CCSR_SSI_SRCR_RXDIR;
   scr |= CCSR_SSI_SCR_SYN;
   }
 
 --
 To unsubscribe from this list: send the line unsubscribe linux-kernel in
 the body of a message to majord...@vger.kernel.org
 More majordomo info at  http://vger.kernel.org/majordomo-info.html
 Please read the FAQ at  http://www.tux.org/lkml/
 

-- 
Pengutronix e.K.   | |
Industrial Linux Solutions | http://www.pengutronix.de/  |
Peiner Str. 6-8, 31137 Hildesheim, Germany | Phone: +49-5121-206917-0|
Amtsgericht Hildesheim, HRA 2686   | Fax:   +49-5121-206917- |


signature.asc
Description: Digital signature
___
Linuxppc-dev mailing list
Linuxppc-dev@lists.ozlabs.org
https://lists.ozlabs.org/listinfo/linuxppc-dev

[PATCH 6/6] ASoC: fsl_ssi: adjust set DAI format in AC'97 mode

2015-06-28 Thread Maciej S. Szmigiero
Adjust set DAI format function in fsl_ssi driver so it
doesn't fail and clears RXDIR in AC'97 mode.

Signed-off-by: Maciej Szmigiero m...@maciej.szmigiero.name
---
 sound/soc/fsl/fsl_ssi.c |8 +---
 1 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/sound/soc/fsl/fsl_ssi.c b/sound/soc/fsl/fsl_ssi.c
index e79dc16..d043c7c 100644
--- a/sound/soc/fsl/fsl_ssi.c
+++ b/sound/soc/fsl/fsl_ssi.c
@@ -900,14 +900,16 @@ static int _fsl_ssi_set_dai_fmt(struct device *dev,
scr = ~CCSR_SSI_SCR_SYS_CLK_EN;
break;
default:
-   return -EINVAL;
+   if (!fsl_ssi_is_ac97(ssi_private))
+   return -EINVAL;
}
 
stcr |= strcr;
srcr |= strcr;
 
-   if (ssi_private-cpu_dai_drv.symmetric_rates) {
-   /* Need to clear RXDIR when using SYNC mode */
+   if (ssi_private-cpu_dai_drv.symmetric_rates
+   || fsl_ssi_is_ac97(ssi_private)) {
+   /* Need to clear RXDIR when using SYNC or AC97 mode */
srcr = ~CCSR_SSI_SRCR_RXDIR;
scr |= CCSR_SSI_SCR_SYN;
}

___
Linuxppc-dev mailing list
Linuxppc-dev@lists.ozlabs.org
https://lists.ozlabs.org/listinfo/linuxppc-dev